==> jc-1.4.0.tar.gz: soot/jimple/NoSuchLocalException.h <==
// public class soot.jimple.NoSuchLocalException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 22e9e7fc6bd40b94 soot_jimple_NoSuchLocalException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_jimple_NoSuchLocalException_H_
#define _JC_soot_jimple_NoSuchLocalException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_NoSuchLocalException$sub_refs	_jc_soot_jimple_NoSuchLocalException$sub_refs;
typedef struct _jc_soot_jimple_NoSuchLocalException$sub_nonrefs	_jc_soot_jimple_NoSuchLocalException$sub_nonrefs;
typedef struct _jc_soot_jimple_NoSuchLocalException$refs	_jc_soot_jimple_NoSuchLocalException$refs;
typedef struct _jc_soot_jimple_NoSuchLocalException$nonrefs	_jc_soot_jimple_NoSuchLocalException$nonrefs;
typedef struct _jc_soot_jimple_NoSuchLocalException$object	_jc_soot_jimple_NoSuchLocalException$object;

typedef const struct _jc_soot_jimple_NoSuchLocalException$vmethods	_jc_soot_jimple_NoSuchLocalException$vmethods;
typedef const struct _jc_soot_jimple_NoSuchLocalException$vtable	_jc_soot_jimple_NoSuchLocalException$vtable;
typedef const struct _jc_soot_jimple_NoSuchLocalException$vtype	_jc_soot_jimple_NoSuchLocalException$vtype;

// Constructors
extern void _jc_soot_jimple_NoSuchLocalException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_NoSuchLocalException$object *);
extern void _jc_soot_jimple_NoSuchLocalException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_NoSuchLocalException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_jimple_NoSuchLocalException$vmethods {
};

// Vtable
struct _jc_soot_jimple_NoSuchLocalException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_jimple_NoSuchLocalException$vmethods	soot_jimple_NoSuchLocalException;
};

// Vtype
struct _jc_soot_jimple_NoSuchLocalException$vtype {
	_jc_type			type;
	_jc_soot_jimple_NoSuchLocalException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_NoSuchLocalException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_NoSuchLocalException$refs {
    _jc_soot_jimple_NoSuchLocalException$sub_refs	soot_jimple_NoSuchLocalException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_NoSuchLocalException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_NoSuchLocalException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_jimple_NoSuchLocalException$sub_nonrefs	soot_jimple_NoSuchLocalException;
};

// Object instance structure
struct _jc_soot_jimple_NoSuchLocalException$object {
	_jc_soot_jimple_NoSuchLocalException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_NoSuchLocalException$vtype	*vtype;
	_jc_soot_jimple_NoSuchLocalException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_NoSuchLocalException$vtype _jc_soot_jimple_NoSuchLocalException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_NoSuchLocalException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_NoSuchLocalException$class_object;

#endif	/* _JC_soot_jimple_NoSuchLocalException_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/NoSuchLocalException.h <==
// public class soot.jimple.NoSuchLocalException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 22e9e7fc6bd40b94 soot_jimple_NoSuchLocalException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_jimple_NoSuchLocalException_H_
#define _JC_soot_jimple_NoSuchLocalException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_NoSuchLocalException$sub_refs	_jc_soot_jimple_NoSuchLocalException$sub_refs;
typedef struct _jc_soot_jimple_NoSuchLocalException$sub_nonrefs	_jc_soot_jimple_NoSuchLocalException$sub_nonrefs;
typedef struct _jc_soot_jimple_NoSuchLocalException$refs	_jc_soot_jimple_NoSuchLocalException$refs;
typedef struct _jc_soot_jimple_NoSuchLocalException$nonrefs	_jc_soot_jimple_NoSuchLocalException$nonrefs;
typedef struct _jc_soot_jimple_NoSuchLocalException$object	_jc_soot_jimple_NoSuchLocalException$object;

typedef const struct _jc_soot_jimple_NoSuchLocalException$vmethods	_jc_soot_jimple_NoSuchLocalException$vmethods;
typedef const struct _jc_soot_jimple_NoSuchLocalException$vtable	_jc_soot_jimple_NoSuchLocalException$vtable;
typedef const struct _jc_soot_jimple_NoSuchLocalException$vtype	_jc_soot_jimple_NoSuchLocalException$vtype;

// Constructors
extern void _jc_soot_jimple_NoSuchLocalException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_NoSuchLocalException$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_NoSuchLocalException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_NoSuchLocalException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_NoSuchLocalException$vmethods {
};

// Vtable
struct _jc_soot_jimple_NoSuchLocalException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_jimple_NoSuchLocalException$vmethods	soot_jimple_NoSuchLocalException;
};

// Vtype
struct _jc_soot_jimple_NoSuchLocalException$vtype {
	_jc_type			type;
	_jc_soot_jimple_NoSuchLocalException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_NoSuchLocalException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_NoSuchLocalException$refs {
    _jc_soot_jimple_NoSuchLocalException$sub_refs	soot_jimple_NoSuchLocalException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_NoSuchLocalException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_NoSuchLocalException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_jimple_NoSuchLocalException$sub_nonrefs	soot_jimple_NoSuchLocalException;
};

// Object instance structure
struct _jc_soot_jimple_NoSuchLocalException$object {
	_jc_soot_jimple_NoSuchLocalException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_NoSuchLocalException$vtype	*vtype;
	_jc_soot_jimple_NoSuchLocalException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_NoSuchLocalException$vtype _jc_soot_jimple_NoSuchLocalException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_NoSuchLocalException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_NoSuchLocalException$class_object;

#endif	/* _JC_soot_jimple_NoSuchLocalException_H_ */
